@@ -4,8 +4,8 @@ from unittest import TestCase
 from .mock import call
 from testfixtures import ShouldRaise, compare
 
-from testfixtures.popen import MockPopen
-from testfixtures.compat import PY2
+from testfixtures.popen import MockPopen, PopenBehaviour
+from testfixtures.compat import BytesLiteral, PY2
 
 import signal
 
@@ -55,6 +55,22 @@ class Tests(TestCase):
                 call.Popen_instance.communicate(),
                 ], Popen.mock.method_calls)
 
+    def test_callable_default_behaviour(self):
+        def some_callable(command, stdin):
+            return PopenBehaviour(BytesLiteral(command), BytesLiteral(stdin), 1, 345, 0)
+
+        Popen = MockPopen()
+        Popen.set_default(behaviour=some_callable)
+
+        process = Popen('a command', stdin='some stdin', stdout=PIPE, stderr=PIPE)
+        compare(process.pid, 345)
+
+        out, err = process.communicate()
+
+        compare(out, b'a command')
+        compare(err, b'some stdin')
+        compare(process.returncode, 1)
+
     def test_command_is_sequence(self):
         Popen = MockPopen()
         Popen.set_command('a command')
@@ -150,6 +166,19 @@ class Tests(TestCase):
                 call.Popen('a command', shell=True, stderr=PIPE, stdout=PIPE),
                 ], Popen.mock.method_calls)
 
+    def test_write_to_stdin(self):
+        # setup
+        Popen = MockPopen()
+        Popen.set_command('a command')
+        # usage
+        process = Popen('a command', stdin=PIPE, shell=True)
+        process.stdin.write('some text')
+        # test call list
+        compare([
+                call.Popen('a command', shell=True, stdin=PIPE),
+                call.Popen_instance.stdin.write('some text'),
+                ], Popen.mock.method_calls)
+
     def test_wait_and_return_code(self):
         # setup
         Popen = MockPopen()
